@@ -132,7 +132,7 @@ class CortxJupyter(ContentsManager):
             return (yield _delete__notebook_checkpoint(self._config(), checkpoint_id, path))
 
     def _config(self):
-        cred_file = open(".credentials","w")
+        # cred_file = open(".credentials","w")
         configuration  = Config(
             region=self.region_name,
             bucket_name=self.bucket_name,
@@ -142,6 +142,9 @@ class CortxJupyter(ContentsManager):
             multipart_uploads=self.multipart_uploads,
             endpoint_url=self.endpoint_url
         )
-        cred_file.write(json.dumps(configuration._asdict()))
+        print(configuration._asdict())
+        with open(".credentials", "w") as fp:
+            json.dump(configuration._asdict() , fp)
+        # cred_file.write(json.dumps(configuration._asdict()))
         return configuration
 
